# run this spec twice to compile. Why, I don't know...

Name:           mupdf
Version:        1.24.1
Release:        %mkrel 1
Summary:     Lightweight PDF viewer and toolkit written in portable C
License:        GPLv3
Group:          Office
URL:             https://mupdf.com/
Source1:        %{name}.desktop
Source2:        %{name}-gl.desktop

#--------------------------------------------
BuildRequires: lzip
BuildRequires: desktop-file-utils
BuildRequires: freeglut-devel
BuildRequires: harfbuzz-devel
BuildRequires: jbig2dec-devel
BuildRequires: jpeg-devel
BuildRequires: lcms2-devel
BuildRequires: mesa-devel
BuildRequires: lib64openjpeg-devel
BuildRequires: lib64gumbo-devel
BuildRequires: zlib1-devel
BuildRequires: lib64x11-devel
BuildRequires: lib64xext-devel
BuildRequires: lib64curl-devel
BuildRequires: lib64freetype6-devel
#--------------------------------------------

%description
MuPDF is a lightweight PDF viewer and toolkit written in portable C.

The renderer in MuPDF is tailored for high quality anti-aliased
graphics.  MuPDF renders text with metrics and spacing accurate to
within fractions of a pixel for the highest fidelity in reproducing
the look of a printed page on screen.

MuPDF has a small footprint.  A binary that includes the standard
Roman fonts is only one megabyte.  A build with full CJK support
(including an Asian font) is approximately five megabytes.

MuPDF has support for all non-interactive PDF 1.7 features, and the
toolkit provides a simple API for accessing the internal structures of
the PDF document.  Example code for navigating interactive links and
bookmarks, encrypting PDF files, extracting fonts, images, and
searchable text, and rendering pages to image files is provided.

%prep

%build
export LDFLAGS="-L/usr/lib64/libglvnd/ $LDFLAGS"
pushd %_sourcedir
wget -nc https://mupdf.com/downloads/archive/mupdf-%{version}-source.tar.gz
### was tar.lz  then use tar --lzip
tar -xf %{name}-%{version}-source.tar.gz -C %_builddir
popd

pushd %_builddir/%name-%{version}-source

echo > user.make "\
  USE_SYSTEM_FREETYPE := yes
  USE_SYSTEM_HARFBUZZ := yes
  USE_SYSTEM_JBIG2DEC := yes
  USE_SYSTEM_JPEGXR := yes # not used without HAVE_JPEGXR
  USE_SYSTEM_LCMS2 := no # need lcms2-art fork
  USE_SYSTEM_LIBJPEG := yes
  USE_SYSTEM_MUJS := no # build needs source anyways
  USE_SYSTEM_OPENJPEG := yes
  USE_SYSTEM_ZLIB := yes
  USE_SYSTEM_GLUT := no # need freeglut2-art frok
  USE_SYSTEM_CURL := yes
  USE_SYSTEM_GUMBO := yes
"

%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export XCFLAGS="%{optflags} -fPIC -DJBIG_NO_MEMENTO -DTOFU -DTOFU_CJK_EXT"
make %{?_smp_mflags} build=release verbose=yes
popd

%install
rm -rf %{buildroot}

pushd %_builddir/%{name}-%{version}-source
%make_install build=release prefix=%{_prefix} libdir=%{_libdir}
rm -rf %{buildroot}%{_datadir}/doc/%{name}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -p -m644 docs/logo/mupdf-logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/mupdf.svg
install -p -m644 docs/logo/mupdf-logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/mupdf-gl.svg
popd

install -Dpm 0644 %SOURCE1 %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dpm 0644 %SOURCE2 %{buildroot}%{_datadir}/applications/%{name}-gl.desktop
# handle docs
rm -rf %{buildroot}%{_defaultdocdir}

# symlink
ln -s %{name}-x11 %{buildroot}%{_bindir}/%{name}

# fix file attributes (fedora)
find %{buildroot}%{_mandir} -type f -exec chmod 0644 {} \;

#drop this
rm -f %{buildroot}/%{_libdir}/libmu*.a
rm -rf %{buildroot}/%{_includedir}


%post
update-desktop-database &> /dev/null || :
%update_menus

%postun
update-desktop-database &> /dev/null || :
%clean_menus

%clean
rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/%{name}-%{version}-source

%files
%{_bindir}/*
%{_datadir}/applications/mupdf*.desktop
%{_datadir}/icons/hicolor
%{_mandir}/man1/*.1.*


%changelog
* Sat Apr 13 2024 pp <pp> 1.24.1-1pclos2024
- new version

* Sun Mar 24 2024 pp <pp> 1.24.0-1pclos2024
- new version

* Fri Feb 23 2024 pp <pp> 1.23.11-1pclos2024
- new version

* Fri Feb 09 2024 pp <pp> 1.23.10-1pclos2024
- new version

* Fri Jan 12 2024 pp <pp> 1.23.9-1pclos2024
- new version

* Mon Dec 18 2023 pp <pp> 1.23.7-1pclos2023
- new version

* Thu Nov 23 2023 pp <pp> 1.23.6-1pclos2023
- new version

* Mon Nov 06 2023 pp <pp> 1.23.5-1pclos2023
- new version

* Fri Oct 20 2023 pp <pp> 1.23.4-1pclos2023
- new version

* Sat Sep 09 2023 pp <pp> 1.23.3-1pclos2023
- new version

* Thu Aug 31 2023 pp <pp> 1.23.1-1pclos2023
- new version

* Tue Jun 27 2023 pp <pp> 1.22.2-1pclos2023
- new version

* Mon May 15 2023 pp <pp> 1.22.1-1pclos2023
- new version

* Sun Apr 23 2023 pp <pp> 1.22.0-1pclos2023
- new version

* Tue Dec 20 2022 pp <pp> 1.21.1-1pclos2022
- new version

* Sat Nov 26 2022 pp <pp> 1.21.0-1pclos2022
- new version

* Thu Sep 08 2022 pp <pp> 1.20.3-1pclos2022
- new version

* Wed Jun 15 2022 pp <pp> 1.20.0-1pclos2022
- new version

* Sat Apr 23 2022 pp <pp> 1.19.1-1pclos2022
- new version

* Sat Oct 16 2021 pp <pp> 1.19.0-1pclos2021
- update

* Fri Oct 09 2020 pp <pp> 1.18.0-1pclos2020
- update

* Sat Jul 18 2020 ghostbunny <ghostbunny at gmx dot de> 1.17.0-1pclos2020
- 1.17.0

* Tue Sep 24 2019 pp <pp> - 1.16.1-1pclos2019
- update

* Sat Jan 13 2018 bb2 <bb2> - 1.12.0-2pclos2018
- clean up specfile

* Mon Jan 08 2018 Zen Subz <techars21 at gmail dot com> - 1.12.0-1pclos2018
- Updated build for PCLinuxOS
